@@ -34,7 +34,7 @@ setMethod("cgarchspec", signature(uspec = "uGARCHmultispec"), .cgarchspec)
 	pars = unlist(value)
 	names(pars) = parnames = names(pars)
 	# included parameters in model
-	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ])
+	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ,drop=FALSE])
 	inc = NULL
 	for(i in seq_along(parnames)){
 		if(is.na(match(parnames[i], modelnames))){
@@ -77,7 +77,7 @@ setReplaceMethod(f="setfixed", signature= c(object = "cGARCHspec", value = "vect
 	pars = unlist(value)
 	names(pars) = parnames = names(pars)
 	# included parameters in model
-	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ])
+	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ,drop=FALSE])
 	inc = NULL
 	for(i in seq_along(parnames)){
 		if(is.na(match(parnames[i], modelnames))){
