@@ -62,7 +62,7 @@ setMethod(f = "dccspec", signature(uspec = "uGARCHmultispec"), definition = .xdc
 	pars = unlist(value)
 	names(pars) = parnames = tolower(names(pars))
 	# included parameters in model
-	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ])
+	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ,drop=FALSE])
 	inc = NULL
 	for(i in seq_along(parnames)){
 		if(is.na(match(parnames[i], modelnames))){
@@ -110,7 +110,7 @@ setReplaceMethod(f="setfixed", signature= c(object = "DCCspec", value = "vector"
 	pars = unlist(value)
 	names(pars) = parnames = tolower(names(pars))
 	# included parameters in model
-	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ])
+	modelnames = rownames(ipars[which(ipars[,4]==1 | ipars[,2]==1), ,drop=FALSE])
 	inc = NULL
 	for(i in seq_along(parnames)){
 		if(is.na(match(parnames[i], modelnames))){
